@@ -2,7 +2,7 @@ package Module::Install::XSUtil;
 
 use 5.005_03;
 
-$VERSION = '0.35';
+$VERSION = '0.37';
 
 use Module::Install::Base;
 @ISA     = qw(Module::Install::Base);
@@ -25,7 +25,7 @@ my %BuildRequires = (
 );
 
 my %Requires = (
-    'XSLoader' => 0.10, # the newer, the better
+    'XSLoader' => 0.02,
 );
 
 my %ToInstall;
@@ -66,7 +66,7 @@ sub _xs_initialize{
                 $self->makemaker_args->{OPTIMIZE} = '-Zi';
             }
             else{
-                $self->makemaker_args->{OPTIMIZE} = '-g';
+                $self->makemaker_args->{OPTIMIZE} = '-g -ggdb -g3';
             }
             $self->cc_define('-DXS_ASSERT');
         }
@@ -96,9 +96,13 @@ sub _is_msvc{
 
     my $want_xs;
     sub want_xs {
-        my $default = @_ ? shift : 1; # you're using this module, you /must/ want XS by default
+        my($self, $default) = @_;
         return $want_xs if defined $want_xs;
 
+        # you're using this module, you must want XS by default
+        # unless PERL_ONLY is true.
+        $default = !$ENV{PERL_ONLY} if not defined $default;
+
         foreach my $arg(@ARGV){
             if($arg eq '--pp'){
                 return $want_xs = 0;
@@ -231,7 +235,7 @@ C99
 
     $tmpfile->close();
 
-    system $Config{cc}, '-c', $tmpfile->filename;
+    system "$Config{cc} -c " . $tmpfile->filename;
 
     (my $objname = File::Basename::basename($tmpfile->filename)) =~ s/\Q.c\E$/$Config{_o}/;
     unlink $objname or warn "Cannot unlink $objname (ignored): $!";
@@ -776,7 +780,7 @@ Module::Install::XSUtil - Utility functions for XS modules
 
 =head1 VERSION
 
-This document describes Module::Install::XSUtil version 0.35.
+This document describes Module::Install::XSUtil version 0.37.
 
 =head1 SYNOPSIS
 
@@ -806,7 +810,7 @@ This document describes Module::Install::XSUtil version 0.35.
     # This is a special version of requires().
     # If XS::SomeFeature provides header files,
     # this will add its include paths into INC
-    requies_xs 'XS::SomeFeature';
+    requires_xs 'XS::SomeFeature';
 
 
 =head1 DESCRIPTION
@@ -821,7 +825,7 @@ See L<XS::MRO::Compat> and L<Method::Cumulative> for example.
 =head2 cc_available
 
 Returns true if a C compiler is available. YOU DO NOT NEED TO CALL
-THIS FUNCTION YOURSELF: it will be called for you when this module is 
+THIS FUNCTION YOURSELF: it will be called for you when this module is
 initialized, and your Makefile.PL process will exit with 0 status.
 Only explicitly call if you need to do some esoteric handling when
 no compiler is available (for example, when you have a pure perl alternative)
@@ -835,7 +839,7 @@ Returns true if a C compiler is available and it supports C99 features.
 Returns true if the user asked for the XS version or pure perl version of the
 module.
 
-Will return true if C<--xs> is explicitly specified as the argument to 
+Will return true if C<--xs> is explicitly specified as the argument to
 F<Makefile.PL>, and false if C<--pp> is specified. If neither is explicitly
 specified, will return the value specified by C<$default>. If you do not
 specify the value of C<$default>, then it will be true.
@@ -892,7 +896,7 @@ e.g.:
 
 =head2 cc_assert_lib %args
 
-Checks if the given C library is installed via Devel::CheckLib. 
+Checks if the given C library is installed via Devel::CheckLib.
 Takes exactly what Devel::CheckLib takes. Note that you must pass
 the path names explicitly.
 
